@@ -1,7 +1,7 @@
 package RxPerl;
 use 5.010;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use RxPerl::Operators::Creation ':all';
 use RxPerl::Operators::Pipeable ':all';
@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.16.0";
+our $VERSION = "v0.16.1";
 
 1;
 __END__
