@@ -1,6 +1,6 @@
 package RxPerl::Observable;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use RxPerl::Subscription;
 use RxPerl::Subscriber;
@@ -25,7 +25,7 @@ use Carp 'croak';
 #   (body)      This method calls the $function that RxPerl::Observable->new received as argument (and that initiates the subscription)
 #   (return)    This method returns a new RxPerl::Subscription object, that contains the "cleanup subref" returned by $function
 
-our $VERSION = "v0.16.0";
+our $VERSION = "v0.16.1";
 
 sub new {
     my ($class, $function) = @_;
