@@ -1,6 +1,6 @@
 package RxPerl::Operators::Pipeable;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use RxPerl::Operators::Creation 'rx_observable', 'rx_subject';
 use RxPerl::ConnectableObservable;
