@@ -1,10 +1,10 @@
 package RxPerl::Subscription;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use Scalar::Util 'blessed', 'reftype', 'weaken';
 
-our $VERSION = "v0.16.0";
+our $VERSION = "v0.16.1";
 
 sub new {
     my ($class) = @_;
